Report VDSM-Scatter-heatmap-infomation
VDSM_scatter_heat(X, f, p, Anchor.estimate, Anchor.model = NULL)A m*p matrix which contains m different p-dimensional models. All the elements are either 0 or 1.
A vector with m elements which represent each model's frequency in X.
The number of variate in the model
An estimation for the anchor model
A vector containing p elements with either 1 or 0 value and must be found in X. Default is the model with the highest frequency.
A list of information which helps to plot VDSM-Scatter-heatmap.